@@ -1,4 +1,4 @@
-`Auto.VR` <-
+Auto.VR <-
 function(y)
 {
     coe <- AR1(y)$ALPHA
@@ -7,11 +7,7 @@ function(y)
     vrsum <- 1
     for (i in 1:(T-1))
     {
-        sum1 <- 0
-        for (t in 1:(T-i))
-        {
-        sum1 <- sum1 + y[t]*y[t+i]
-        }
+    sum1 <- sum(y[1:(T-i)] * y[(1+i):T])
     sum1 <- sum1/(sum(y^2))
     vrsum <- vrsum + 2*kfunc(i/lq)*sum1
     }
