@@ -1,4 +1,4 @@
-`LMCD` <-
+LMCD <-
 function(y,kvec)
 {
     y <- as.matrix(y)
